@@ -1,6 +1,8 @@
 /* Generated file - edit enums.py instead! */
 namespace sigrok {
 
+template<> const SR_API std::map<const enum sr_loglevel, const LogLevel * const> EnumValue<LogLevel, enum sr_loglevel>::_values;
+
 /** Log verbosity level */
 class SR_API LogLevel : public EnumValue<LogLevel, enum sr_loglevel>
 {
@@ -30,6 +32,8 @@ protected:
 	static const LogLevel _SPEW;
 };
 
+template<> const SR_API std::map<const enum sr_datatype, const DataType * const> EnumValue<DataType, enum sr_datatype>::_values;
+
 /** Configuration data type */
 class SR_API DataType : public EnumValue<DataType, enum sr_datatype>
 {
@@ -63,6 +67,8 @@ protected:
 	static const DataType _MQ;
 };
 
+template<> const SR_API std::map<const enum sr_packettype, const PacketType * const> EnumValue<PacketType, enum sr_packettype>::_values;
+
 /** Type of datafeed packet */
 class SR_API PacketType : public EnumValue<PacketType, enum sr_packettype>
 {
@@ -78,8 +84,6 @@ public:
 	static const PacketType * const TRIGGER;
 	/** Payload is struct */
 	static const PacketType * const LOGIC;
-	/** DEPRECATED! Use SR_DF_ANALOG instead. */
-	static const PacketType * const ANALOG_OLD;
 	/** Beginning of frame. */
 	static const PacketType * const FRAME_BEGIN;
 	/** End of frame. */
@@ -95,12 +99,13 @@ protected:
 	static const PacketType _META;
 	static const PacketType _TRIGGER;
 	static const PacketType _LOGIC;
-	static const PacketType _ANALOG_OLD;
 	static const PacketType _FRAME_BEGIN;
 	static const PacketType _FRAME_END;
 	static const PacketType _ANALOG;
 };
 
+template<> const SR_API std::map<const enum sr_mq, const Quantity * const> EnumValue<Quantity, enum sr_mq>::_values;
+
 /** Measured quantity */
 class SR_API Quantity : public EnumValue<Quantity, enum sr_mq>
 {
@@ -162,6 +167,8 @@ public:
 	static const Quantity * const APPARENT_POWER;
 	/** Mass. */
 	static const Quantity * const MASS;
+	/** Harmonic ratio. */
+	static const Quantity * const HARMONIC_RATIO;
 
 protected:
     Quantity(enum sr_mq id, const char name[]) : EnumValue(id, name) {}
@@ -198,8 +205,11 @@ protected:
 	static const Quantity _POWER_FACTOR;
 	static const Quantity _APPARENT_POWER;
 	static const Quantity _MASS;
+	static const Quantity _HARMONIC_RATIO;
 };
 
+template<> const SR_API std::map<const enum sr_unit, const Unit * const> EnumValue<Unit, enum sr_unit>::_values;
+
 /** Unit of measurement */
 class SR_API Unit : public EnumValue<Unit, enum sr_unit>
 {
@@ -229,7 +239,7 @@ public:
 	static const Unit * const SECOND;
 	/** Unit of conductance, the inverse of resistance. */
 	static const Unit * const SIEMENS;
-	/** An absolute measurement of power, in decibels, referenced to 1 milliwatt (dBu). */
+	/** An absolute measurement of power, in decibels, referenced to 1 milliwatt (dBm). */
 	static const Unit * const DECIBEL_MW;
 	/** Voltage in decibel, referenced to 1 volt (dBV). */
 	static const Unit * const DECIBEL_VOLT;
@@ -322,6 +332,8 @@ protected:
 	static const Unit _PIECE;
 };
 
+template<> const SR_API std::map<const enum sr_mqflag, const QuantityFlag * const> EnumValue<QuantityFlag, enum sr_mqflag>::_values;
+
 /** Flag applied to measured quantity */
 class SR_API QuantityFlag : public EnumValue<QuantityFlag, enum sr_mqflag>
 {
@@ -369,13 +381,15 @@ public:
 	static const QuantityFlag * const REFERENCE;
 	/** Unstable value (hasn't settled yet). */
 	static const QuantityFlag * const UNSTABLE;
+	/** Measurement is four wire (e.g. */
+	static const QuantityFlag * const FOUR_WIRE;
 	/** Get flags corresponding to a bitmask. */
-	static vector<const QuantityFlag *>
+	static std::vector<const QuantityFlag *>
 		flags_from_mask(unsigned int mask);
 
 	/** Get bitmask corresponding to a set of flags. */
 	static unsigned int mask_from_flags(
-		vector<const QuantityFlag *> flags);
+		std::vector<const QuantityFlag *> flags);
 
 
 protected:
@@ -402,8 +416,11 @@ protected:
 	static const QuantityFlag _AVG;
 	static const QuantityFlag _REFERENCE;
 	static const QuantityFlag _UNSTABLE;
+	static const QuantityFlag _FOUR_WIRE;
 };
 
+template<> const SR_API std::map<const enum sr_trigger_matches, const TriggerMatchType * const> EnumValue<TriggerMatchType, enum sr_trigger_matches>::_values;
+
 /** Trigger match type */
 class SR_API TriggerMatchType : public EnumValue<TriggerMatchType, enum sr_trigger_matches>
 {
@@ -429,6 +446,8 @@ protected:
 	static const TriggerMatchType _UNDER;
 };
 
+template<> const SR_API std::map<const enum sr_output_flag, const OutputFlag * const> EnumValue<OutputFlag, enum sr_output_flag>::_values;
+
 /** Flag applied to output modules */
 class SR_API OutputFlag : public EnumValue<OutputFlag, enum sr_output_flag>
 {
@@ -443,6 +462,8 @@ protected:
 	static const OutputFlag _INTERNAL_IO_HANDLING;
 };
 
+template<> const SR_API std::map<const enum sr_channeltype, const ChannelType * const> EnumValue<ChannelType, enum sr_channeltype>::_values;
+
 /** Channel type */
 class SR_API ChannelType : public EnumValue<ChannelType, enum sr_channeltype>
 {
@@ -460,6 +481,8 @@ protected:
 	static const ChannelType _ANALOG;
 };
 
+template<> const SR_API std::map<const enum sr_configcap, const Capability * const> EnumValue<Capability, enum sr_configcap>::_values;
+
 /** Configuration capability */
 class SR_API Capability : public EnumValue<Capability, enum sr_configcap>
 {
@@ -480,6 +503,8 @@ protected:
 	static const Capability _LIST;
 };
 
+template<> const SR_API std::map<const enum sr_configkey, const ConfigKey * const> EnumValue<ConfigKey, enum sr_configkey>::_values;
+
 /** Configuration key */
 class SR_API ConfigKey : public EnumValue<ConfigKey, enum sr_configkey>
 {
@@ -511,6 +536,10 @@ public:
 	static const ConfigKey * const ELECTRONIC_LOAD;
 	/** The device can act as a scale. */
 	static const ConfigKey * const SCALE;
+	/** The device can act as a function generator. */
+	static const ConfigKey * const SIGNAL_GENERATOR;
+	/** The device can measure power. */
+	static const ConfigKey * const POWERMETER;
 	/** Specification on how to connect to a device. */
 	static const ConfigKey * const CONN;
 	/** Serial communication specification, in the form: */
@@ -617,6 +646,32 @@ public:
 	static const ConfigKey * const EQUIV_CIRCUIT_MODEL;
 	/** Over-temperature protection (OTP) active. */
 	static const ConfigKey * const OVER_TEMPERATURE_PROTECTION_ACTIVE;
+	/** Under-voltage condition. */
+	static const ConfigKey * const UNDER_VOLTAGE_CONDITION;
+	/** Under-voltage condition active. */
+	static const ConfigKey * const UNDER_VOLTAGE_CONDITION_ACTIVE;
+	/** Trigger level. */
+	static const ConfigKey * const TRIGGER_LEVEL;
+	/** Under-voltage condition threshold. */
+	static const ConfigKey * const UNDER_VOLTAGE_CONDITION_THRESHOLD;
+	/** Which external clock source to use if the device supports multiple external clock channels. */
+	static const ConfigKey * const EXTERNAL_CLOCK_SOURCE;
+	/** Offset of a source without strictly-defined MQ. */
+	static const ConfigKey * const OFFSET;
+	/** The device supports setting a pattern for the logic trigger. */
+	static const ConfigKey * const TRIGGER_PATTERN;
+	/** High resolution mode. */
+	static const ConfigKey * const HIGH_RESOLUTION;
+	/** Peak detection. */
+	static const ConfigKey * const PEAK_DETECTION;
+	/** Logic threshold: predefined levels (TTL, ECL, CMOS, etc). */
+	static const ConfigKey * const LOGIC_THRESHOLD;
+	/** Logic threshold: custom numerical value. */
+	static const ConfigKey * const LOGIC_THRESHOLD_CUSTOM;
+	/** The measurement range of a DMM or the output range of a power supply. */
+	static const ConfigKey * const RANGE;
+	/** The number of digits (e.g. */
+	static const ConfigKey * const DIGITS;
 	/** Session filename. */
 	static const ConfigKey * const SESSIONFILE;
 	/** The device supports specifying a capturefile to inject. */
@@ -629,6 +684,8 @@ public:
 	static const ConfigKey * const DATA_SOURCE;
 	/** The device supports setting a probe factor. */
 	static const ConfigKey * const PROBE_FACTOR;
+	/** Number of powerline cycles for ADC integration time. */
+	static const ConfigKey * const ADC_POWERLINE_CYCLES;
 	/** The device supports setting a sample time limit (how long the sample acquisition should run, in ms). */
 	static const ConfigKey * const LIMIT_MSEC;
 	/** The device supports setting a sample number limit (how many samples should be acquired). */
@@ -646,13 +703,14 @@ public:
     /** Data type used for this configuration key. */
     const DataType *data_type() const;
     /** String identifier for this configuration key, suitable for CLI use. */
-    string identifier() const;
+    std::string identifier() const;
     /** Description of this configuration key. */
-    string description() const;
+    std::string description() const;
     /** Get configuration key by string identifier. */
-    static const ConfigKey *get_by_identifier(string identifier);
+    static const ConfigKey *get_by_identifier(std::string identifier);
     /** Parse a string argument into the appropriate type for this key. */
-    Glib::VariantBase parse_string(string value) const;
+    static Glib::VariantBase parse_string(std::string value, enum sr_datatype dt);
+    Glib::VariantBase parse_string(std::string value) const;
 
 
 protected:
@@ -671,6 +729,8 @@ protected:
 	static const ConfigKey _LCRMETER;
 	static const ConfigKey _ELECTRONIC_LOAD;
 	static const ConfigKey _SCALE;
+	static const ConfigKey _SIGNAL_GENERATOR;
+	static const ConfigKey _POWERMETER;
 	static const ConfigKey _CONN;
 	static const ConfigKey _SERIALCOMM;
 	static const ConfigKey _MODBUSADDR;
@@ -724,12 +784,26 @@ protected:
 	static const ConfigKey _MEASURED_QUANTITY;
 	static const ConfigKey _EQUIV_CIRCUIT_MODEL;
 	static const ConfigKey _OVER_TEMPERATURE_PROTECTION_ACTIVE;
+	static const ConfigKey _UNDER_VOLTAGE_CONDITION;
+	static const ConfigKey _UNDER_VOLTAGE_CONDITION_ACTIVE;
+	static const ConfigKey _TRIGGER_LEVEL;
+	static const ConfigKey _UNDER_VOLTAGE_CONDITION_THRESHOLD;
+	static const ConfigKey _EXTERNAL_CLOCK_SOURCE;
+	static const ConfigKey _OFFSET;
+	static const ConfigKey _TRIGGER_PATTERN;
+	static const ConfigKey _HIGH_RESOLUTION;
+	static const ConfigKey _PEAK_DETECTION;
+	static const ConfigKey _LOGIC_THRESHOLD;
+	static const ConfigKey _LOGIC_THRESHOLD_CUSTOM;
+	static const ConfigKey _RANGE;
+	static const ConfigKey _DIGITS;
 	static const ConfigKey _SESSIONFILE;
 	static const ConfigKey _CAPTUREFILE;
 	static const ConfigKey _CAPTURE_UNITSIZE;
 	static const ConfigKey _POWER_OFF;
 	static const ConfigKey _DATA_SOURCE;
 	static const ConfigKey _PROBE_FACTOR;
+	static const ConfigKey _ADC_POWERLINE_CYCLES;
 	static const ConfigKey _LIMIT_MSEC;
 	static const ConfigKey _LIMIT_SAMPLES;
 	static const ConfigKey _LIMIT_FRAMES;
